package model;

import java.util.LinkedList;
import java.util.List;

public class Alarm implements Comparable<Alarm>, Operable, ObservableSubject {
    private String name;
    private Time time;
    private boolean enabled;
    private List<Observer> observers = new LinkedList<Observer>();
    public Alarm() {
    	name = null;
    	time = null;
    	enabled = true;
    }
    public Alarm(String name, String time)
    throws BadHourException, BadMinuteException, BadFormatException {
        this.name = name;
        this.time = new Time(time);
    }
    public String getName() {
        return name;
	}
	public void setName(String name) {
		this.name = name;
	}
	public Time getTime() {
		return time;
	}
	public void setTime(Time t) {
		time = t;
	}
	public void setTime(String time)
    throws BadHourException, BadMinuteException, BadFormatException {
		this.time = new Time(time);
	}
	public void setEnabled() {
		enabled = true;
	}
	public boolean isEnabled() {
		return enabled;
	}
	public void setDisabled() {
		enabled = false;
	}
	public String toString() {
		if (enabled) return time + " : " + name;
		return time + " : ( " + name + " )";
	}
	public int compareTo(Alarm o) {
		int resultForTimes = time.compareTo(o.time);
		if (resultForTimes == 0)
			return name.compareTo(o.name);
		return resultForTimes;
	}
	public void performs(Operation op) throws Exception {
		op.doItOn(this);
	}
	public void addObserver(Observer o) {
		observers.add(o);
		System.out.println("add : " + observers.size());
	}
	public void removeObserver(Observer o) {
		observers.remove(o);
		System.out.println("remove : " + observers.size());
	}
	public void notifyObservers() {
		System.out.println("notify : " + observers.size());
		for(Observer o : observers) o.update();
	}
}
